@@ -1,7 +1,8 @@
-use std::string::ToString;
-use std::str::FromStr;
+use std::{str::FromStr, string::ToString};
+
 use crate::Error;
 
+/// DID URL string
 #[derive(Serialize, Deserialize, Debug)]
 pub struct DidUrl(pub String);
 
@@ -16,10 +17,9 @@ impl FromStr for DidUrl {
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         let re = regex::Regex::new(r"(?x)(?P<prefix>[did]{3}):(?P<method>[a-z]*):").unwrap();
         if re.is_match(s) {
-            Ok(Self{0: s.to_string()})
+            Ok(Self { 0: s.to_string() })
         } else {
             Err(Error::BadDid)
         }
     }
 }
-
